Kas yra OiRA? | OiRA

Temos

# Kas yra OiRA?

## Pirmą kartą naudojatės OiRA?

Čia trumpai supažindinama su rizikos vertinimu ir kaip OiRA gali jums padėti jį atlikti.

## Kas yra rizikos vertinimas?

Rizikos vertinimas yra sėkmingo darbuotojų saugos ir sveikatos valdymo pagrindas ir pagrindinė su darbu susijusių nelaimingų atsitikimų ir profesinių ligų prevencijos priemonė. Jei ji bus tinkamai įgyvendinta, ji gali pagerinti darbuotojų saugą ir sveikatą bei bendrus įmonės veiklos rezultatus.

Darbuotojų sauga ir sveikata Europoje užtikrinama vertinant ir valdant riziką darbe. Darbdaviai turi teisinę pareigą užtikrinti darbuotojų saugą ir sveikatą visais su darbu susijusiais aspektais ir atlikti rizikos vertinimą. Todėl kiekviena įmonė turi atlikti rizikos vertinimą ir parengti veiksmų planą. Kad darbo vietos rizikos vertinimas būtų veiksmingas, visi susiję subjektai turi aiškiai suvokti:

- teisinį pagrindą ir sąvokas;
- rizikos vertinimo procesą;
- veiksmus, kuriuos turi atlikti pagrindiniai proceso dalyviai.

Darbuotojai ir (arba) jų atstovai turi teisę pateikti savo nuomonę dėl rizikos vertinimo atlikimo ir gali jame dalyvauti.

Daugiau informacijos apie rizikos vertinimą ir darbuotojų ir (arba) jų atstovų dalyvavimą rizikos vertinimo procese rasite projekto OiRA svetainėje.

## Kas yra OiRA?

OiRA - tai internetinė interaktyvi rizikos vertinimo priemonė. Tai internetinė taikomoji programa, kuria naudodamiesi galite atlikti savo darbo vietos saugos ir sveikatos rizikos vertinimą.

## Kam OiRA skirta?

OiRA gali naudoti bet kas darbo vietoje saugai ir sveikatai kylančiai rizikai įvertinti.

Tačiau OiRA naudingiausia mažesnėms įmonėms. OiRA specialiai sukurta taip, kad padėtų smulkioms įmonėms įvertinti riziką darbe ir parengti rizikos vertinimo dokumentus, įskaitant ir įmonės reikalavimus atitinkantį veiksmų planą.

## Ką turiu daryti?

OiRA rizikos vertinimo procese yra keli etapai:

- Pasirengimas: kai kuriose priemonėse yra klausimai apie įmonės profilį, padėsiantys pritaikyti priemonę prie jūsų įmonės ypatumų. Atsakius į klausimus apie profilį, priemonė pritaikoma konkrečiai jums bei nurodomi jums tinkami moduliai.

- Dalyvavimas: kiekvienas rizikos vertinimas turėtų būti atliekamas aktyviai dalyvaujant darbuotojams. Kad informuotumėte darbuotojus ir gautumėte jų atsiliepimus, su šia priemone galite atspausdinti visą rizikos vertinimo tekstą arba jo dalis.

- Rizikos nustatymas: OiRA nurodo, kokie su sauga ir sveikata susiję rizikos veiksniai arba problemos gali atsirasti jūsų darbo vietoje. Į teiginius ir (arba) klausimus atsakydami „taip“ arba „ne“, nurodykite, ar tokių rizikos veiksnių arba problemų yra. Į klausimą nereikia atsakyti iš karto - galima jį pasižymėti ir atsakyti vėliau.

- Vertinimas: kai kuriose priemonėse prašoma jūsų nustatytus rizikos veiksnius suskirstyti pagal svarbą. Tai galima padaryti įvairiais būdais, priklausomai nuo nacionalinių OiRA partnerių ir (arba) priemonių kūrėjų priimtų sprendimų bei jų konkretaus požiūrio. Kai kuriose priemonėse rizikos veiksniai suskirstomi pagal svarbą automatiškai, tačiau galima to nepaisyti.

- Veiksmų planas: kiekvienam nustatytam rizikos veiksniui reikia pasirinkti vieną ar kelias priemones, kurios jį pašalintų ar sumažintų. Daugelis priemonių jums pasiūlys priemones. Tačiau visada galite įrašyti savo nustatytas priemones.

- Ataskaita: jūs teisiškai privalote dokumentuoti savo rizikos vertinimą. Ataskaitų skyriuje rasite įvairių ataskaitų, kurios padės jums stebėti savo rizikos vertinimą ir imtis tolesnių veiksmų, siekiant pašalinti arba sumažinti nustatytus rizikos veiksnius.

## Kiek visa tai užtruks?

Numatyti, kiek apskritai užtruks vertinimas, neįmanoma, nes priemonės skiriasi priklausomai nuo sektoriaus ir šalies.

Tačiau vertinimui galite skirti tiek laiko, kiek tuo metu leidžia jūsų aplinkybės, o padarius pertrauką vėl tęsti darbą jums patogiu metu.

## Kodėl turiu užsiregistruoti?

Pradėjus pirmąjį rizikos vertinimą, jūsų iš karto paprašys susikurti OiRA paskyrą - tai atliekama paprastai ir greitai.

Užsiregistravę bet kada galėsite prisijungti ir tęsti jau pradėtus vertinimus arba imtis naujų.

Jei esate registruotas naudotojas, taip pat turite galimybę bet kada atsispausdinti naujausią tikslų rizikos įvertinimą.

## Ar man reikia pasiruošti?

Prieš pradedant naudotis priemone, jums nereikia jokio specialaus pasirengimo, tačiau vertėtų apsispręsti, kas vykdys rizikos vertinimą ir kaip į šį procesą bus įtraukiami darbuotojai.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More